==> j2sdk-1_4_2_04-i586-3.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_zh_TW.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_zh_TW extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "*" },
        { "FileChooser.cancelButtonText", "\u53D6\u6D88" },
        { "FileChooser.cancelButtonToolTipText", "\u4E2D\u65B7\u6A94\u6848\u9078\u64C7\u7A0B\u5F0F\u5C0D\u8A71\u65B9\u584A\u3002" },
        { "FileChooser.deleteFileButtonText", "\u522A\u9664\u6A94\u6848" },
        { "FileChooser.filesLabelText", "\u6A94\u6848" },
        { "FileChooser.foldersLabelText", "\u6A94\u6848\u593E" },
        { "FileChooser.newFolderButtonText", "\u65B0\u6A94\u6848\u593E" },
        { "FileChooser.openButtonText", "\u78BA\u5B9A" },
        { "FileChooser.openButtonToolTipText", "\u958B\u555F\u9078\u53D6\u7684\u6A94\u6848\u3002" },
        { "FileChooser.openDialogTitleText", "\u958B\u555F" },
        { "FileChooser.pathLabelText", "\u9078\u53D6:" },
        { "FileChooser.renameFileButtonText", "\u91CD\u65B0\u547D\u540D\u6A94\u6848" },
        { "FileChooser.saveButtonText", "\u5132\u5B58" },
        { "FileChooser.saveButtonToolTipText", "\u5132\u5B58\u9078\u53D6\u7684\u6A94\u6848\u3002" },
        { "FileChooser.saveDialogTitleText", "\u5132\u5B58" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\u85CD(B):" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\u984F\u8272\u540D\u7A31(N):" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\u7DA0(G):" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\u8272\u8ABF(H):" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK Color Chooser" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "\u7D05(R):" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\u98FD\u548C(S):" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\u503C(V):" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}

==> j2sdk-1_5_0_01-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_zh_TW.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_zh_TW extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "\u6240\u6709\u6A94\u6848" },
        { "FileChooser.cancelButtonText", "\u53D6\u6D88" },
        { "FileChooser.cancelButtonToolTipText", "\u4E2D\u65B7\u6A94\u6848\u9078\u64C7\u7A0B\u5F0F\u5C0D\u8A71\u65B9\u584A\u3002" },
        { "FileChooser.deleteFileButtonText", "\u522A\u9664\u6A94\u6848" },
        { "FileChooser.filesLabelText", "\u6A94\u6848" },
        { "FileChooser.filterLabelText", "\u904E\u6FFE\u5668:" },
        { "FileChooser.foldersLabelText", "\u6A94\u6848\u593E" },
        { "FileChooser.newFolderButtonText", "\u65B0\u6A94\u6848\u593E" },
        { "FileChooser.newFolderDialogText", "\u6A94\u6848\u593E\u540D\u7A31:" },
        { "FileChooser.openButtonText", "\u78BA\u5B9A" },
        { "FileChooser.openButtonToolTipText", "\u958B\u555F\u9078\u53D6\u7684\u6A94\u6848\u3002" },
        { "FileChooser.openDialogTitleText", "\u958B\u555F" },
        { "FileChooser.pathLabelText", "\u9078\u53D6:" },
        { "FileChooser.renameFileButtonText", "\u91CD\u65B0\u547D\u540D\u6A94\u6848" },
        { "FileChooser.renameFileDialogText", "\u5C07\u6A94\u6848 \"{0}\" \u91CD\u65B0\u547D\u540D\u70BA" },
        { "FileChooser.renameFileErrorText", "\u5C07\u6A94\u6848 \"{0}\" \u91CD\u65B0\u547D\u540D\u70BA \"{1}\" \u6642\u51FA\u73FE\u932F\u8AA4" },
        { "FileChooser.renameFileErrorTitle", "\u932F\u8AA4" },
        { "FileChooser.saveButtonText", "\u5132\u5B58" },
        { "FileChooser.saveButtonToolTipText", "\u5132\u5B58\u9078\u53D6\u7684\u6A94\u6848\u3002" },
        { "FileChooser.saveDialogTitleText", "\u5132\u5B58" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\u85CD(B):" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\u984F\u8272\u540D\u7A31(N):" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\u7DA0(G):" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\u8272\u8ABF(H):" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK Color Chooser" },
        { "GTKColorChooserPanel.redMnemonic", "69" },
        { "GTKColorChooserPanel.redText", "\u7D05(E):" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\u98FD\u548C(S):" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\u503C(V):" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}
